@@ -75,8 +75,8 @@ def goto_assignments(request_data):
 _old_definitions = {}
 
 
-def _extract_def(d):
-    d_line, d_column = d.start_pos
+def _extract_def(d, path):
+    d_line, d_column = d.line, d.column
     # use full name for import type
     if d.type == 'function':
         try:
@@ -87,15 +87,16 @@ def _extract_def(d):
     else:
         name = d.name
     definition = Definition(name, d_line - 1, d_column,
-                            icon_from_typename(d.name, d.type))
+                            icon_from_typename(d.name, d.type),
+                            file_path=path)
     # check for methods in class or nested methods/classes
     if d.type == "class" or d.type == 'function':
         try:
-            sub_definitions = d.defined_names()
+            sub_definitions = d.names()
             for sub_d in sub_definitions:
                 if (d.type == 'function' and sub_d.type == 'function') or \
                         d.type == 'class':
-                    definition.add_child(_extract_def(sub_d))
+                    definition.add_child(_extract_def(sub_d, path))
         except (AttributeError, IndexError):
             pass
     return definition
@@ -108,13 +109,12 @@ def defined_names(request_data):
     global _old_definitions
     ret_val = []
     path = request_data['path']
-    toplvl_definitions = jedi.defined_names(
+    toplvl_definitions = jedi.names(
         request_data['code'], path, 'utf-8')
     for d in toplvl_definitions:
-        definition = _extract_def(d)
+        definition = _extract_def(d, path)
         if d.type != 'import':
             ret_val.append(definition)
-    _logger().debug("Document structure changed %s")
     ret_val = [d.to_dict() for d in ret_val]
     return ret_val
 
@@ -135,7 +135,7 @@ def quick_doc(request_data):
     except jedi.NotFoundError:
         return []
     else:
-        ret_val = [d.doc for d in definitions]
+        ret_val = [d.docstring() for d in definitions]
         return ret_val
 
 
@@ -150,6 +150,10 @@ def run_pep8(request_data):
     WARNING = 1
     code = request_data['code']
     path = request_data['path']
+    max_line_length = request_data['max_line_length']
+    ignore_rules = request_data['ignore_rules']
+    ignore_rules += ['W291', 'W292', 'W293', 'W391']
+    pep8.MAX_LINE_LENGTH = max_line_length
     # setup our custom style guide with our custom checker which returns a list
     # of strings instread of spitting the results at stdout
     pep8style = pep8.StyleGuide(parse_argv=False, config_file='',
@@ -163,7 +167,10 @@ def run_pep8(request_data):
     else:
         messages = []
         for line_number, offset, code, text, doc in results:
-            messages.append(('[PEP8] %s' % text, WARNING, line_number - 1))
+            if code in ignore_rules:
+                continue
+            messages.append(('[PEP8] %s: %s' % (code, text), WARNING,
+                             line_number - 1))
         return messages
 
 
@@ -228,6 +235,16 @@ def run_pyflakes(request_data):
     return ret_val
 
 
+ICON_CLASS = ('code-class', ':/pyqode_python_icons/rc/class.png')
+ICON_FUNC = ('code-function', ':/pyqode_python_icons/rc/func.png')
+ICON_FUNC_PRIVATE = ('code-function', ':/pyqode_python_icons/rc/func_priv.png')
+ICON_FUNC_PROTECTED = ('code-function',
+                       ':/pyqode_python_icons/rc/func_prot.png')
+ICON_NAMESPACE = ('code-context', ':/pyqode_python_icons/rc/namespace.png')
+ICON_VAR = ('code-variable', ':/pyqode_python_icons/rc/var.png')
+ICON_KEYWORD = ('quickopen', ':/pyqode_python_icons/rc/keyword.png')
+
+
 def icon_from_typename(name, icon_type):
     """
     Returns the icon resource filename that corresponds to the given typename.
@@ -238,25 +255,27 @@ def icon_from_typename(name, icon_type):
 
     :returns: The associate icon resource filename or None.
     """
-    ICONS = {'CLASS': ':/pyqode_python_icons/rc/class.png',
-             'IMPORT': ':/pyqode_python_icons/rc/namespace.png',
-             'STATEMENT': ':/pyqode_python_icons/rc/var.png',
-             'FORFLOW': ':/pyqode_python_icons/rc/var.png',
-             'FORSTMT': ':/pyqode_python_icons/rc/var.png',
-             'WITHSTMT': ':/pyqode_python_icons/rc/var.png',
-             'GLOBALSTMT': ':/pyqode_python_icons/rc/var.png',
-             'MODULE': ':/pyqode_python_icons/rc/namespace.png',
-             'KEYWORD': ':/pyqode_python_icons/rc/keyword.png',
-             'PARAM': ':/pyqode_python_icons/rc/var.png',
-             'ARRAY': ':/pyqode_python_icons/rc/var.png',
-             'INSTANCEELEMENT': ':/pyqode_python_icons/rc/var.png',
-             'INSTANCE': ':/pyqode_python_icons/rc/var.png',
-             'PARAM-PRIV': ':/pyqode_python_icons/rc/var.png',
-             'PARAM-PROT': ':/pyqode_python_icons/rc/var.png',
-             'FUNCTION': ':/pyqode_python_icons/rc/func.png',
-             'DEF': ':/pyqode_python_icons/rc/func.png',
-             'FUNCTION-PRIV': ':/pyqode_python_icons/rc/func_priv.png',
-             'FUNCTION-PROT': ':/pyqode_python_icons/rc/func_prot.png'}
+    ICONS = {
+        'CLASS': ICON_CLASS,
+        'IMPORT': ICON_NAMESPACE,
+        'STATEMENT': ICON_VAR,
+        'FORFLOW': ICON_VAR,
+        'FORSTMT': ICON_VAR,
+        'WITHSTMT': ICON_VAR,
+        'GLOBALSTMT': ICON_VAR,
+        'MODULE': ICON_NAMESPACE,
+        'KEYWORD': ICON_KEYWORD,
+        'PARAM': ICON_VAR,
+        'ARRAY': ICON_VAR,
+        'INSTANCEELEMENT': ICON_VAR,
+        'INSTANCE': ICON_VAR,
+        'PARAM-PRIV': ICON_VAR,
+        'PARAM-PROT': ICON_VAR,
+        'FUNCTION': ICON_FUNC,
+        'DEF': ICON_FUNC,
+        'FUNCTION-PRIV': ICON_FUNC_PRIVATE,
+        'FUNCTION-PROT': ICON_FUNC_PROTECTED
+    }
     ret_val = None
     icon_type = icon_type.upper()
     # jedi 0.8 introduced NamedPart class, which have a string instead of being
